Coverage for src/su6/__init__.py: 100%

1"""

2 This file exposes 'app' to the module.

3"""

4

5# SPDX-FileCopyrightText: 2023-present Robin van der Noord <robinvandernoord@gmail.com>

6#

7# SPDX-License-Identifier: MIT

8

9 from rich import print # noqa: import is there for library reasons

10

11 from .cli import app # noqa: import is there for library reasons

12 from .core import ( # noqa: import is there for library reasons

13 GREEN_CIRCLE,

14 RED_CIRCLE,

15 print_json,

16 state,

17)

18

19# for plugins:

20 from .plugins import ( # noqa: import is there for library reasons

21 register as register_plugin,

22)

23 from .plugins import run_tool # noqa: import is there for library reasons